LmCodecs class abstract final

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

enumByName<T extends Enum>(List<T> values) LmParamCodec<T>

Constants

bool → const LmParamCodec<bool>
dateTimeIso8601 → const LmParamCodec<DateTime>
double → const LmParamCodec<double>
int → const LmParamCodec<int>
string → const LmParamCodec<String>