LmCustomTransition class final

Inheritance

Constructors

LmCustomTransition({LmTransitionBuilder? builder, String? debugLabel, Duration duration = const Duration(milliseconds: 300), Duration? reverseDuration, Curve curve = Curves.easeInOut})
const

Properties

builder LmTransitionBuilder?
final
curve Curve
finalinherited
debugLabel String?
final
duration Duration
finalinherited
gesturePopEnabled bool
finalinherited
hashCode int
The hash code for this object.
no setterinherited
reverseDuration Duration
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited