LmSlideTransition class final

Inheritance

Constructors

LmSlideTransition({LmSlideFrom from = LmSlideFrom.right, Duration duration = const Duration(milliseconds: 500), Duration? reverseDuration, Curve curve = Curves.easeOutCubic})
const

Properties

curve Curve
finalinherited
duration Duration
finalinherited
from LmSlideFrom
final
gesturePopEnabled bool
finalinherited
hashCode int
The hash code for this object.
no setterinherited
reverseDuration Duration
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited