LmNavigationState class final

Constructors

LmNavigationState({required String activeBranchId, required Map<String, LmBranchState> branches, required LmLocation location, List<LmModalNode> modalStack = const [], int version = 0})

Properties

activeBranchId String
final
branches Map<String, LmBranchState>
final
hashCode int
The hash code for this object.
no setterinherited
location LmLocation
final
modalStack List<LmModalNode>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
version int
final

Methods

copyWith({String? activeBranchId, Map<String, LmBranchState>? branches, LmLocation? location, List<LmModalNode>? modalStack, int? version}) LmNavigationState
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited