LmRenderedTree class final

Constructors

LmRenderedTree({required LmRenderedTreeKind kind, required String activeBranchId, List<LmRouteNode> compactStack = const [], List<LmRouteNode> primaryStack = const [], List<LmRouteNode> secondaryStack = const [], List<LmRouteNode> overlayStack = const [], List<LmRouteNode> modalStack = const []})
const

Properties

activeBranchId String
final
compactStack List<LmRouteNode>
final
hashCode int
The hash code for this object.
no setterinherited
kind LmRenderedTreeKind
final
modalStack List<LmRouteNode>
final
overlayStack List<LmRouteNode>
final
primaryStack List<LmRouteNode>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
secondaryStack List<LmRouteNode>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited