LmRouteStateCodec class final

Constructors

LmRouteStateCodec({int schemaVersion = 1})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
schemaVersion int
final

Methods

decode(Map<String, Object?> json) LmNavigationState
encode(LmNavigationState state) Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited