LmRouterDelegate class final

Inheritance
Mixed-in types

Constructors

LmRouterDelegate({required List<LmRouteDefinition<Object?>> routes, required LmLocation initialLocation, List<LmModalRouteDefinition<Object?>> modalRoutes = const [], List<LmBranch> branches = const [], List<LmGuard> guards = const [], LmRouteDefinition<Object?>? notFoundRoute, Listenable? refreshListenable, LmRouterDiagnostics? diagnostics, LmTransitionPolicy transitionPolicy = const LmTransitionPolicy.adaptive(), GlobalKey<NavigatorState>? navigatorKey})

Properties

controller LmNavigationController
latefinal
currentConfiguration LmLocation?
Called by the Router when it detects a route information may have changed as a result of rebuild.
no setteroverride
debugModalMatchCacheSize int
no setter
debugStackCacheSize int
no setter
hashCode int
The hash code for this object.
no setterinherited
hasListeners bool
Whether any listeners are currently registered.
no setterinherited
The key used for retrieving the current navigator.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
build(BuildContext context) Widget
Called by the Router to obtain the widget tree that represents the current state.
override
buildProjectedModalPage(BuildContext context, LmModalNode node) Page<void>
buildProjectedPage(BuildContext context, LmRouteNode node) Page<void>
dispose() → void
Discards any resources used by the object.
override
go(Object location, {LmNavigationSource source = LmNavigationSource.programmaticGo}) Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
pop() Future<bool>
popRoute() Future<bool>
Called by the Router when the Router.backButtonDispatcher reports that the operating system is requesting that the current route be popped.
override
present(Object location) Future<void>
push(Object location) Future<void>
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
replace(Object location) Future<void>
setInitialRoutePath(LmLocation configuration) Future<void>
Called by the Router at startup with the structure that the RouteInformationParser obtained from parsing the initial route.
inherited
setNewRoutePath(LmLocation configuration) Future<void>
Called by the Router when the Router.routeInformationProvider reports that a new route has been pushed to the application by the operating system.
override
setRestoredRoutePath(LmLocation configuration) Future<void>
Called by the Router during state restoration.
inherited
switchBranch(String branchId) Future<void>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited