LmNavigationController class final
- Inheritance
-
- Object
- ChangeNotifier
- LmNavigationController
Constructors
Properties
- canPop → bool
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasListeners → bool
-
Whether any listeners are currently registered.
no setterinherited
- isSystemBackSuppressed → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- state → LmNavigationState
-
no setter
Methods
-
addListener(
VoidCallback listener) → void -
Register a closure to be called when the object changes.
inherited
-
consumeSuppressedSystemBack(
) → bool -
dispose(
) → void -
Discards any resources used by the object.
inherited
-
go(
LmRouteNode route) → LmNavigationTransaction -
goStack(
List< LmRouteNode> routes) → LmNavigationTransaction -
goStackInBranch(
String branchId, List< LmRouteNode> routes) → LmNavigationTransaction -
handleBack(
{LmNavigationSource source = LmNavigationSource.systemBack}) → LmBackResult -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
notifyListeners(
) → void -
Call all the registered listeners.
inherited
-
pop(
) → bool -
present(
LmModalNode modal) → LmNavigationTransaction -
push(
LmRouteNode route) → LmNavigationTransaction -
removeListener(
VoidCallback listener) → void -
Remove a previously registered closure from the list of closures that are
notified when the object changes.
inherited
-
replace(
LmRouteNode route) → LmNavigationTransaction -
suppressNextSystemBack(
{Duration duration = const Duration(seconds: 2)}) → void -
switchBranch(
String branchId) → void -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited