LmNavigationTransaction class final
Constructors
-
const
Properties
- from → LmLocation?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- source → LmNavigationSource
-
final
- startedAt → DateTime
-
final
- to → LmLocation
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
redirectTo(
LmLocation location) → LmNavigationTransaction -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited