LmRouteNode class final
Constructors
-
LmRouteNode({required String name, required String pathPattern, required LmLocation location, required Object? params, required Map<
String, String> query, LmRouteChrome chrome = const LmRouteChrome(), LmDetailPolicy detailPolicy = LmDetailPolicy.pushOnCompact})
Properties
- chrome → LmRouteChrome
-
final
- detailPolicy → LmDetailPolicy
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- location → LmLocation
-
final
- name → String
-
final
- params → Object?
-
final
- pathPattern → String
-
final
-
query
→ Map<
String, String> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited